#ifndef _users_h
#define _users_h

struct Users
{
  int number;
};


#endif // _users_h
